@@ -5,10 +5,12 @@
 //              with the application.
 // ---------------------------------------------------------------------------
 // $Source: src/prelude.rs $
-// $Revision: 2021-12-30T13:42:43+01:00 $
+// $Revision: 2022-01-06T15:46:31+01:00 $
 
 //! This module reexports all macros and types needed to define a quantity.
 
 pub use crate::{Amnt, AmountT, Qty, Quantity, SIPrefix, Unit};
+#[cfg(feature = "fpdec")]
+pub use crate::{Dec, Decimal};
 pub use core::ops::{Div, Mul};
 pub use qty_macros::quantity;
